from django.shortcuts import get_object_or_404,render
from energie.models import Voda
from energie.models import Elektrina
from energie.models import Plyn
from energie.models import Cenotvorba
from datetime import datetime, timedelta

import plotly.express as px
import plotly.graph_objects as go

# Voda ---------------------------------------------------------------------------------------------

def voda_index(request):
    rows = Voda.objects.all()
    context = {
        'voda' : rows
    }
    return render(request,'voda/index.html',context)

def voda_detail(request,id):
    row = get_object_or_404(Voda,id = id)
    context = {
        'voda' : row
    }
    return render(request,'voda/detail.html',context)

def voda_add(request):
    if request.method == 'POST':
        if request.POST.get('datum') and request.POST.get('spotreba'):
            v = Voda()
            v.datum = request.POST.get('datum')
            v.spotreba = request.POST.get('spotreba')
            if Voda.objects.all().first():
                v.rozdiel_spotreby = float(v.spotreba) - float(request.POST.get('predosla_spotreba'))
                d1 = datetime.strptime(v.datum,"%Y-%m-%d")
                d2 = datetime.strptime(request.POST.get('predosly_datum'),"%Y-%m-%d")
                days = (d1 - d2).days
                if days > 0:
                    if v.rozdiel_spotreby > 0:
                        v.denna_spotreba = v.rozdiel_spotreby / days
                    else:
                        context = {
                            'status' : {'id':1,'text':'Zadal si nižšiu, resp. rovnakú spotrebu ako predošlá spotreba!'}
                        }
                        return render(request,'voda/status.html',context)  
                else:
                    context = {
                        'status' : {'id':1,'text':'Zadal si starší, resp. rovnaký dátum!'}
                    }
                    return render(request,'voda/status.html',context)
                if Cenotvorba.objects.all().first(): # ak existuje zaznam v tabulke Cenotvorba
                    row = Cenotvorba.objects.get(id = 1) # vyber zaznamu z tabulky
                    v.cena_za_rozdiel_spotreby = v.rozdiel_spotreby * row.voda_cena_za_1m3 + days * row.voda_pevna_cena_na_den
                    v.pevna_cena_na_den_pri_vypocte = row.voda_pevna_cena_na_den
                    v.cena_za_1m3_pri_vypocte = row.voda_cena_za_1m3
                else: # ak neexistuje zaznam v tabulke Cenotvorba
                    v.cena_za_rozdiel_spotreby = 0
                    v.pevna_cena_na_den_pri_vypocte = 0
                    v.cena_za_1m3_pri_vypocte = 0
            else:
                v.rozdiel_spotreby = 0.0
                v.denna_spotreba = 0.0
                v.cena_za_rozdiel_spotreby = 0.0
                v.pevna_cena_na_den_pri_vypocte = 0.0
                v.cena_za_1m3_pri_vypocte = 0.0
            v.save()
            context = {
                'status' : {'id':0,'text':'Nový záznam bol úspešne pridaný.'}
            }
            return render(request,'voda/status.html',context)
        context = {
            'status' : {'id':1,'text':'Nezadal si potrebné údaje!'}
        }
        return render(request,'voda/status.html',context)
    else:
        if Voda.objects.all().first():
            max_datum = Voda.objects.latest('datum').datum
            row = Voda.objects.get(datum = max_datum)
            context = {
                'v' : row
            }
            return render(request,'voda/add.html',context)
        else:
            context = {
                'v' : {'datum':datetime.now(),'spotreba':0,'rozdiel_spotreby':0,'denna_spotreba':0,'cena_za_rozdiel_spotreby':0}
            }
            return render(request,'voda/add.html',context)

def voda_del(request,id):
    if request.method == 'POST':
        if 'del_yes' in request.POST:
            Voda.objects.filter(id = id).delete()
            context = {
                'status' : {'id':0,'text':'Záznam bol úspešne zmazaný.'}
            }
        else:
            context = {
                'status' : {'id':1,'text':'Záznam nebol zmazaný!'}
            }
        return render(request,'voda/status.html',context)
    else:
        row = get_object_or_404(Voda,id = id)
        context = {
            'voda' : row
        }
        return render(request,'voda/del.html',context)

# Elektrina ----------------------------------------------------------------------------------------

def elektrina_index(request):
    rows = Elektrina.objects.all()
    context = {
        'elektrina' : rows
    }
    return render(request,'elektrina/index.html',context)

def elektrina_detail(request,id):
    row = get_object_or_404(Elektrina,id = id)
    context = {
        'elektrina' : row
    }
    return render(request,'elektrina/detail.html',context)

def elektrina_add(request):
    if request.method == 'POST':
        if request.POST.get('datum') and request.POST.get('spotreba_den'):
            e = Elektrina()
            e.datum = request.POST.get('datum')
            e.spotreba_den = request.POST.get('spotreba_den')
            e.spotreba_noc = request.POST.get('spotreba_noc')
            if Elektrina.objects.all().first():
                e.rozdiel_spotreby_den = float(e.spotreba_den) - float(request.POST.get('predosla_spotreba_den'))
                e.rozdiel_spotreby_noc = float(e.spotreba_noc) - float(request.POST.get('predosla_spotreba_noc'))
                d1 = datetime.strptime(e.datum,"%Y-%m-%d")
                d2 = datetime.strptime(request.POST.get('predosly_datum'),"%Y-%m-%d")
                days = (d1 - d2).days
                if days > 0:
                    if e.rozdiel_spotreby_den > 0:
                        e.denna_spotreba_den = e.rozdiel_spotreby_den / days
                    else:
                        context = {
                            'status' : {'id':1,'text':'Zadal si nižšiu, resp. rovnakú DENNÚ spotrebu ako predošlá spotreba!'}
                        }
                        return render(request,'elektrina/status.html',context)
                    if e.rozdiel_spotreby_noc > 0:
                        e.denna_spotreba_noc = e.rozdiel_spotreby_noc / days
                    else:
                        context = {
                            'status' : {'id':1,'text':'Zadal si nižšiu, resp. rovnakú NOČNÚ spotrebu ako predošlá spotreba!'}
                        }
                        return render(request,'elektrina/status.html',context)  
                else:
                    context = {
                        'status' : {'id':1,'text':'Zadal si starší, resp. rovnaký dátum!'}
                    }
                    return render(request,'elektrina/status.html',context)
                if Cenotvorba.objects.all().first(): # ak existuje zaznam v tabulke Cenotvorba
                    row = Cenotvorba.objects.get(id = 1) # vyber zaznamu z tabulky
                    e.cena_za_rozdiel_spotreby_den = e.rozdiel_spotreby_den * row.elektrina_cena_za_1kWh_den + days * row.elektrina_pevna_cena_na_den_den
                    e.cena_za_rozdiel_spotreby_noc = e.rozdiel_spotreby_noc * row.elektrina_cena_za_1kWh_noc + days * row.elektrina_pevna_cena_na_den_noc
                    e.pevna_cena_na_den_pri_vypocte_den = row.elektrina_pevna_cena_na_den_den
                    e.pevna_cena_na_den_pri_vypocte_noc = row.elektrina_pevna_cena_na_den_noc
                    e.cena_za_1kWh_pri_vypocte_den = row.elektrina_cena_za_1kWh_den
                    e.cena_za_1kWh_pri_vypocte_noc = row.elektrina_cena_za_1kWh_noc
                else: # ak neexistuje zaznam v tabulke Cenotvorba
                    e.cena_za_rozdiel_spotreby_den = 0
                    e.cena_za_rozdiel_spotreby_noc = 0
                    e.pevna_cena_na_den_pri_vypocte_den = 0
                    e.pevna_cena_na_den_pri_vypocte_noc = 0
                    e.cena_za_1kWh_pri_vypocte_den = 0
                    e.cena_za_1kWh_pri_vypocte_noc = 0
            else:
                e.rozdiel_spotreby_den = 0.0
                e.rozdiel_spotreby_noc = 0.0
                e.denna_spotreba_den = 0.0
                e.denna_spotreba_noc = 0.0
                e.cena_za_rozdiel_spotreby_den = 0
                e.cena_za_rozdiel_spotreby_noc = 0
                e.pevna_cena_na_den_pri_vypocte_den = 0
                e.pevna_cena_na_den_pri_vypocte_noc = 0
                e.cena_za_1kWh_pri_vypocte_den = 0
                e.cena_za_1kWh_pri_vypocte_noc = 0
            e.save()
            context = {
                'status' : {'id':0,'text':'Nový záznam bol úspešne pridaný.'}
            }
            return render(request,'elektrina/status.html',context)
        context = {
            'status' : {'id':1,'text':'Nezadal si potrebné údaje!'}
        }
        return render(request,'elektrina/status.html',context)
    else:
        if Elektrina.objects.all().first():
            max_datum = Elektrina.objects.latest('datum').datum
            row = Elektrina.objects.get(datum = max_datum)
            context = {
                'e' : row
            }
            return render(request,'elektrina/add.html',context)
        else:
            context = {
                'e' : {'datum':datetime.now(),'spotreba_den':0,'rozdiel_spotreby_den':0,'denna_spotreba_den':0,'cena_za_rozdiel_spotreby_den':0,
                                              'spotreba_noc':0,'rozdiel_spotreby_noc':0,'denna_spotreba_noc':0,'cena_za_rozdiel_spotreby_noc':0}
            }
            return render(request,'elektrina/add.html',context)

def elektrina_del(request,id):
    if request.method == 'POST':
        if 'del_yes' in request.POST:
            Elektrina.objects.filter(id = id).delete()
            context = {
                'status' : {'id':0,'text':'Záznam bol úspešne zmazaný.'}
            }
        else:
            context = {
                'status' : {'id':1,'text':'Záznam nebol zmazaný!'}
            }
        return render(request,'elektrina/status.html',context)
    else:
        row = get_object_or_404(Elektrina,id = id)
        context = {
            'elektrina' : row
        }
        return render(request,'elektrina/del.html',context)

# Plyn ---------------------------------------------------------------------------------------------

def plyn_index(request):
    rows = Plyn.objects.all()
    context = {
        'plyn' : rows
    }
    return render(request,'plyn/index.html',context)

def plyn_detail(request,id):
    row = get_object_or_404(Plyn,id = id)
    context = {
        'plyn' : row
    }
    return render(request,'plyn/detail.html',context)

def plyn_add(request):
    if request.method == 'POST':
        if request.POST.get('datum') and request.POST.get('spotreba'):
            p = Plyn()
            p.datum = request.POST.get('datum')
            p.spotreba = request.POST.get('spotreba')
            if Plyn.objects.all().first():
                p.rozdiel_spotreby = float(p.spotreba) - float(request.POST.get('predosla_spotreba'))
                d1 = datetime.strptime(p.datum,"%Y-%m-%d")
                d2 = datetime.strptime(request.POST.get('predosly_datum'),"%Y-%m-%d")
                days = (d1 - d2).days
                if days > 0:
                    if p.rozdiel_spotreby > 0:
                        p.denna_spotreba = p.rozdiel_spotreby / days
                    else:
                        context = {
                            'status' : {'id':1,'text':'Zadal si nižšiu, resp. rovnakú spotrebu ako predošlá spotreba!'}
                        }
                        return render(request,'plyn/status.html',context)  
                else:
                    context = {
                        'status' : {'id':1,'text':'Zadal si starší, resp. rovnaký dátum!'}
                    }
                    return render(request,'plyn/status.html',context)
                if Cenotvorba.objects.all().first(): # ak existuje zaznam v tabulke Cenotvorba
                    row = Cenotvorba.objects.get(id = 1) # vyber zaznamu z tabulky
                    p.cena_za_rozdiel_spotreby = p.rozdiel_spotreby * row.plyn_cena_za_1m3 + days * row.plyn_pevna_cena_na_den
                    p.pevna_cena_na_den_pri_vypocte = row.plyn_pevna_cena_na_den
                    p.cena_za_1m3_pri_vypocte = row.plyn_cena_za_1m3
                else: # ak neexistuje zaznam v tabulke Cenotvorba
                    p.cena_za_rozdiel_spotreby = 0
                    p.pevna_cena_na_den_pri_vypocte = 0
                    p.cena_za_1m3_pri_vypocte = 0
            else:
                p.rozdiel_spotreby = 0.0
                p.denna_spotreba = 0.0
                p.cena_za_rozdiel_spotreby = 0.0
                p.pevna_cena_na_den_pri_vypocte = 0.0
                p.cena_za_1m3_pri_vypocte = 0.0
            p.save()
            context = {
                'status' : {'id':0,'text':'Nový záznam bol úspešne pridaný.'}
            }
            return render(request,'plyn/status.html',context)
        context = {
            'status' : {'id':1,'text':'Nezadal si potrebné údaje!'}
        }
        return render(request,'plyn/status.html',context)
    else:
        if Plyn.objects.all().first():
            max_datum = Plyn.objects.latest('datum').datum
            row = Plyn.objects.get(datum = max_datum)
            context = {
                'p' : row
            }
            return render(request,'plyn/add.html',context)
        else:
            context = {
                'p' : {'datum':datetime.now(),'spotreba':0,'rozdiel_spotreby':0,'denna_spotreba':0,'cena_za_rozdiel_spotreby':0}
            }
            return render(request,'plyn/add.html',context)

def plyn_del(request,id):
    if request.method == 'POST':
        if 'del_yes' in request.POST:
            Plyn.objects.filter(id = id).delete()
            context = {
                'status' : {'id':0,'text':'Záznam bol úspešne zmazaný.'}
            }
        else:
            context = {
                'status' : {'id':1,'text':'Záznam nebol zmazaný!'}
            }
        return render(request,'plyn/status.html',context)
    else:
        row = get_object_or_404(Plyn,id = id)
        context = {
            'plyn' : row
        }
        return render(request,'plyn/del.html',context)

# Cenotvorba ---------------------------------------------------------------------------------------

def settings_cenotvorba(request):
    if Cenotvorba.objects.all().first(): # ak existuje aspon 1 zaznam
        row = Cenotvorba.objects.get(id = 1) # vyber zaznamu z tabulky
        context = {
            's' : row
        }
    else: # ak neexistuje ani 1 zaznam, pouziju sa startovacie udaje
        context = {
            's' : {'voda_pevna_cena_na_den':0.0,'voda_cena_za_1m3':0.0,
                   'elektrina_pevna_cena_na_den_den':0.0,'elektrina_cena_za_1kWh_den':0.0,
                   'elektrina_pevna_cena_na_den_noc':0.0,'elektrina_cena_za_1kWh_noc':0.0,
                   'plyn_pevna_cena_na_den':0.0,'plyn_cena_za_1m3':0.0}
        }
    return render(request,'settings/cenotvorba.html',context)

def settings_cenotvorba_set(request):
    # reakcia na stlacenie tlacidla "Ulož do databázy"
    if request.method == 'POST':
        if Cenotvorba.objects.all().first(): # ak existuje aspon 1 zaznam
            s = Cenotvorba.objects.get(id = 1) # vyber zaznamu z tabulky
        else:
            s = Cenotvorba() # vytvori sa novy zaznam
        s.voda_pevna_cena_na_den = request.POST.get('voda_pevna')
        s.voda_cena_za_1m3 = request.POST.get('voda_za1')
        s.elektrina_pevna_cena_na_den_den = request.POST.get('elektrina_pevna_den')
        s.elektrina_cena_za_1kWh_den = request.POST.get('elektrina_za1_den')
        s.elektrina_pevna_cena_na_den_noc = request.POST.get('elektrina_pevna_noc')
        s.elektrina_cena_za_1kWh_noc = request.POST.get('elektrina_za1_noc')
        s.plyn_pevna_cena_na_den = request.POST.get('plyn_pevna')
        s.plyn_cena_za_1m3 = request.POST.get('plyn_za1')
        s.save()
        context = {
            'status' : {'id':0,'text':'Záznam bol úspešne zmenený.'}
        }
        return render(request,'settings/status.html',context)
    # iba zobrazenie formulara "Uprav ceny"
    if Cenotvorba.objects.all().first(): # ak existuje aspon 1 zaznam
        row = Cenotvorba.objects.get(id = 1) # vyber zaznamu z tabulky
        context = {
            's' : row
        }
    else: # ak neexistuje ani 1 zaznam, pouziju sa startovacie udaje
        context = {
            's' : {'voda_pevna_cena_na_den':0.0,'voda_cena_za_1m3':0.0,
                   'elektrina_pevna_cena_na_den_den':0.0,'elektrina_cena_za_1kWh_den':0.0,
                   'elektrina_pevna_cena_na_den_noc':0.0,'elektrina_cena_za_1kWh_noc':0.0,
                   'plyn_pevna_cena_na_den':0.0,'plyn_cena_za_1m3':0.0}
        }
    return render(request,'settings/cenotvorba_set.html',context)

# Grafy --------------------------------------------------------------------------------------------

def voda_graf(request):
    if Voda.objects.all().first(): # ak existuje aspon 1 zaznam
        rows = Voda.objects.all()

        rok = datetime.today().year # aktualny rok vo formate 2021
        min_time = datetime.min.time()

        date_format = "%d.%m.%Y"
        d1 = datetime.strptime('01.01.' + str(rok),date_format) # 1.1.2021
        d2 = datetime.strptime('31.12.' + str(rok),date_format) # 31.12.2021
        pocet_dni_v_roku = (d2 - d1).days + 1 # pocet dni v aktualnom roku

        # pocet dni do prveho zaznamu v tabulke
        prvy_zaznam = Voda.objects.all().first()
        d2 = datetime.combine(prvy_zaznam.datum,min_time)
        pocet_dni_do_nasledujuceho_zaznamu = (d2 - d1).days + 1

        # pocet dni do posledneho zaznamu v tabulke
        posledny_zaznam = Voda.objects.all().last()
        d2 = datetime.combine(posledny_zaznam.datum,min_time)
        pocet_dni_do_posledneho_zaznamu = (d2 - d1).days + 1
        
        # datumy od 1. do posledneho dna v roku
        di = d1

        x_data = []
        y_data = []
        row_id = 0 # 1. zaznam v tabulke
        v = 0 # denna_spotreba
        # pre vsetky dni v aktualnom roku
        for i in range(1,pocet_dni_v_roku + 1):
            x_data.append(di)
            di = di + timedelta(days = 1) # datum nasledujuceho dna
            if i <= pocet_dni_do_nasledujuceho_zaznamu:
                y_data.append(v) # denna_spotreba
            elif i > pocet_dni_do_posledneho_zaznamu:
                y_data.append(0) # denna_spotreba
            else:
                row_id += 1 # nasledujuci zaznam v tabulke
                # denna_spotreba
                v = rows[row_id].denna_spotreba
                y_data.append(v)
                # pocet dni do nasledujuceho zaznamu v tabulke
                d2 = datetime.combine(rows[row_id].datum,min_time)
                pocet_dni_do_nasledujuceho_zaznamu = (d2 - d1).days + 1

        fig = go.Figure()
        fig.add_trace(go.Scatter(x = x_data,y = y_data,fill = 'tozeroy',
                                 line_color = 'rgba(0,153,204,0.5)',fillcolor = 'rgba(0,153,204,0.5)'))

        # nastavenie stylu grafu
        fig.update_layout(template = 'plotly_dark',
                          paper_bgcolor = 'rgba(0,0,0,0)',
                          plot_bgcolor = 'rgba(0,0,0,0)',
                          title = {'text' : 'Denná spotreba vody','font' : {'color' : 'white'},'x' : 0.5},
                          margin = {'l' : 0,'r' : 0,'t' : 50,'b' : 0,'pad' : 10},
                          xaxis = {'title' : 'Dátum odpočtu','tickformat' : '%d.%m.%Y','linecolor' : 'rgba(0,0,0,0)'},
                          yaxis = {'title' : 'Denná spotreba (m3)','linecolor' : 'rgba(0,0,0,0)'})

        return render(request,"voda/graf.html",context = {'gr1' : fig.to_html()})
    else:
        context = {
            'status' : {'id':1,'text':'V tabuľke nie sú žiadne záznamy!'}
        }
        return render(request,'voda/status.html',context)

def elektrina_graf(request):
    if Elektrina.objects.all().first(): # ak existuje aspon 1 zaznam
        rows = Elektrina.objects.all()

        rok = datetime.today().year # aktualny rok vo formate 2021
        min_time = datetime.min.time()

        date_format = "%d.%m.%Y"
        d1 = datetime.strptime('01.01.' + str(rok),date_format) # 1.1.2021
        d2 = datetime.strptime('31.12.' + str(rok),date_format) # 31.12.2021
        pocet_dni_v_roku = (d2 - d1).days + 1 # pocet dni v aktualnom roku

        # pocet dni do prveho zaznamu v tabulke
        prvy_zaznam = Elektrina.objects.all().first()
        d2 = datetime.combine(prvy_zaznam.datum,min_time)
        pocet_dni_do_nasledujuceho_zaznamu = (d2 - d1).days + 1

        # pocet dni do posledneho zaznamu v tabulke
        posledny_zaznam = Elektrina.objects.all().last()
        d2 = datetime.combine(posledny_zaznam.datum,min_time)
        pocet_dni_do_posledneho_zaznamu = (d2 - d1).days + 1
        
        # datumy od 1. do posledneho dna v roku
        di = d1

        x_data = []
        y_data_den = []
        y_data_noc = []
        row_id = 0 # 1. zaznam v tabulke
        vd = 0 # denna_spotreba_den
        vn = 0 # denna_spotreba_noc
        # pre vsetky dni v aktualnom roku
        for i in range(1,pocet_dni_v_roku + 1):
            x_data.append(di)
            di = di + timedelta(days = 1) # datum nasledujuceho dna
            if i <= pocet_dni_do_nasledujuceho_zaznamu:
                y_data_den.append(vd) # denna_spotreba_den
                y_data_noc.append(vn) # denna_spotreba_noc
            elif i > pocet_dni_do_posledneho_zaznamu:
                y_data_den.append(0) # denna_spotreba_den
                y_data_noc.append(0) # denna_spotreba_noc
            else:
                row_id += 1 # nasledujuci zaznam v tabulke
                # denna_spotreba
                vd = rows[row_id].denna_spotreba_den
                vn = rows[row_id].denna_spotreba_noc
                y_data_den.append(vd)
                y_data_noc.append(vn)
                # pocet dni do nasledujuceho zaznamu v tabulke
                d2 = datetime.combine(rows[row_id].datum,min_time)
                pocet_dni_do_nasledujuceho_zaznamu = (d2 - d1).days + 1

        fig_den = go.Figure()
        fig_den.add_trace(go.Scatter(x = x_data,y = y_data_den,fill = 'tozeroy',
                                     line_color = 'rgba(204,64,64,0.5)',fillcolor = 'rgba(204,64,64,0.5)'))
        fig_noc = go.Figure()
        fig_noc.add_trace(go.Scatter(x = x_data,y = y_data_noc,fill = 'tozeroy',
                                     line_color = 'rgba(204,64,64,0.5)',fillcolor = 'rgba(204,64,64,0.5)'))
        # nastavenie stylu grafu
        fig_den.update_layout(template = 'plotly_dark',
                              paper_bgcolor = 'rgba(0,0,0,0)',
                              plot_bgcolor = 'rgba(0,0,0,0)',
                              title = {'text' : 'Denná spotreba elektriny - denná tarifa','font' : {'color' : 'white'},'x' : 0.5},
                              margin = {'l' : 0,'r' : 0,'t' : 50,'b' : 0,'pad' : 10},
                              xaxis = {'title' : 'Dátum odpočtu','tickformat' : '%d.%m.%Y','linecolor' : 'rgba(0,0,0,0)'},
                              yaxis = {'title' : 'Denná spotreba - denná tarifa (kWh)','linecolor' : 'rgba(0,0,0,0)'})
        fig_noc.update_layout(template = 'plotly_dark',
                              paper_bgcolor = 'rgba(0,0,0,0)',
                              plot_bgcolor = 'rgba(0,0,0,0)',
                              title = {'text' : 'Denná spotreba elektriny - nočná tarifa','font' : {'color' : 'white'},'x' : 0.5},
                              margin = {'l' : 0,'r' : 0,'t' : 50,'b' : 0,'pad' : 10},
                              xaxis = {'title' : 'Dátum odpočtu','tickformat' : '%d.%m.%Y','linecolor' : 'rgba(0,0,0,0)'},
                              yaxis = {'title' : 'Denná spotreba - nočná spotreba (kWh)','linecolor' : 'rgba(0,0,0,0)'})

        return render(request,"elektrina/graf.html",context = {'gr1' : fig_den.to_html(),'gr2' : fig_noc.to_html()})
    else:
        context = {
            'status' : {'id':1,'text':'V tabuľke nie sú žiadne záznamy!'}
        }
        return render(request,'elektrina/status.html',context)

def plyn_graf(request):
    if Plyn.objects.all().first(): # ak existuje aspon 1 zaznam
        rows = Plyn.objects.all()

        rok = datetime.today().year # aktualny rok vo formate 2021
        min_time = datetime.min.time()

        date_format = "%d.%m.%Y"
        d1 = datetime.strptime('01.01.' + str(rok),date_format) # 1.1.2021
        d2 = datetime.strptime('31.12.' + str(rok),date_format) # 31.12.2021
        pocet_dni_v_roku = (d2 - d1).days + 1 # pocet dni v aktualnom roku

        # pocet dni do prveho zaznamu v tabulke
        prvy_zaznam = Plyn.objects.all().first()
        d2 = datetime.combine(prvy_zaznam.datum,min_time)
        pocet_dni_do_nasledujuceho_zaznamu = (d2 - d1).days + 1

        # pocet dni do posledneho zaznamu v tabulke
        posledny_zaznam = Plyn.objects.all().last()
        d2 = datetime.combine(posledny_zaznam.datum,min_time)
        pocet_dni_do_posledneho_zaznamu = (d2 - d1).days + 1
        
        # datumy od 1. do posledneho dna v roku
        di = d1

        x_data = []
        y_data = []
        row_id = 0 # 1. zaznam v tabulke
        v = 0 # denna_spotreba
        # pre vsetky dni v aktualnom roku
        for i in range(1,pocet_dni_v_roku + 1):
            x_data.append(di)
            di = di + timedelta(days = 1) # datum nasledujuceho dna
            if i <= pocet_dni_do_nasledujuceho_zaznamu:
                y_data.append(v) # denna_spotreba
            elif i > pocet_dni_do_posledneho_zaznamu:
                y_data.append(0) # denna_spotreba
            else:
                row_id += 1 # nasledujuci zaznam v tabulke
                # denna_spotreba
                v = rows[row_id].denna_spotreba
                y_data.append(v)
                # pocet dni do nasledujuceho zaznamu v tabulke
                d2 = datetime.combine(rows[row_id].datum,min_time)
                pocet_dni_do_nasledujuceho_zaznamu = (d2 - d1).days + 1

        fig = go.Figure()
        fig.add_trace(go.Scatter(x = x_data,y = y_data,fill = 'tozeroy',
                                 line_color = 'rgba(255,153,0,0.5)',fillcolor = 'rgba(255,153,0,0.5)'))

        # nastavenie stylu grafu
        fig.update_layout(template = 'plotly_dark',
                          paper_bgcolor = 'rgba(0,0,0,0)',
                          plot_bgcolor = 'rgba(0,0,0,0)',
                          title = {'text' : 'Denná spotreba plynu','font' : {'color' : 'white'},'x' : 0.5},
                          margin = {'l' : 0,'r' : 0,'t' : 50,'b' : 0,'pad' : 10},
                          xaxis = {'title' : 'Dátum odpočtu','tickformat' : '%d.%m.%Y','linecolor' : 'rgba(0,0,0,0)'},
                          yaxis = {'title' : 'Denná spotreba (m3)','linecolor' : 'rgba(0,0,0,0)'})

        return render(request,"plyn/graf.html",context = {'gr1' : fig.to_html()})
    else:
        context = {
            'status' : {'id':1,'text':'V tabuľke nie sú žiadne záznamy!'}
        }
        return render(request,'plyn/status.html',context)